'use strict';

var cssSourceMapRebase = require('css-source-map-rebase');

const createCssSourceMapRebasePlugin = (rebase = (_source, _resolvedPath, done) => done()) => {
    return (context, next) => {
        const { resources } = context;
        const resourceHandlers = [];
        for (const resource of resources) {
            const { data, dependencies, name, sourceMap } = resource;
            if (data && sourceMap) {
                const rebaser = new cssSourceMapRebase.Rebaser({
                    map: Buffer.from(JSON.stringify(sourceMap)),
                    rebase
                });
                resourceHandlers.push(rebaser.rebase(data)
                    .then((result) => {
                    const resource = {
                        data: result.css,
                        dependencies,
                        name,
                        sourceMap: JSON.parse(result.map.toString())
                    };
                    return resource;
                }));
            }
        }
        return Promise.all(resourceHandlers)
            .then((resources) => {
            return next({
                resources
            });
        });
    };
};

exports.createCssSourceMapRebasePlugin = createCssSourceMapRebasePlugin;
